import { default as React } from 'react';
import { BlockerFunction, Location } from 'react-router';
import { default as useConfirm } from './hooks/use-confirm';
import { default as usePrompt } from './hooks/use-prompt';
type ReactRouterPromptProps = {
    when: boolean | BlockerFunction;
    children: (data: {
        isActive: boolean;
        onCancel: () => void;
        onConfirm: () => void;
        nextLocation?: Location;
    }) => React.ReactNode;
    beforeCancel?: () => Promise<unknown>;
    beforeConfirm?: (nextLocation?: Location) => Promise<unknown>;
};
/**
 * A replacement component for the react-router `Prompt`.
 * Allows for more flexible dialogs.
 *
 * @example
 * <ReactRouterPrompt when={isDirty}>
 *   {({isActive, onConfirm, onCancel}) => (
 *     <Modal show={isActive}>
 *       <div>
 *         <p>Do you really want to leave?</p>
 *         <button onClick={onCancel}>Cancel</button>
 *         <button onClick={onConfirm}>Ok</button>
 *       </div>
 *     </Modal>
 *   )}
 * </ReactRouterPrompt>
 */
declare function ReactRouterPrompt({ when, children, beforeCancel, beforeConfirm, }: ReactRouterPromptProps): import("react/jsx-runtime").JSX.Element | null;
export { useConfirm, usePrompt };
export default ReactRouterPrompt;
